import * as i0 from '@angular/core';
import { EventEmitter, Component, ViewChild, Output, Input, NgModule } from '@angular/core';
import BpmnJS from 'bpmn-js/dist/bpmn-modeler.production.min.js';
import { switchMap, map, from } from 'rxjs';
import * as i1 from '@angular/common/http';

class NgxThreeoBpmnComponent {
    constructor(http) {
        this.http = http;
        this.importDone = new EventEmitter();
        this.createEnded = new EventEmitter();
        this.connectionAdded = new EventEmitter();
        this.connectionRemoved = new EventEmitter();
        this.shapeRemoved = new EventEmitter();
        this.bpmnJS = new BpmnJS();
        this.bpmnJS.on('import.done', ({ error }) => {
            if (!error) {
                this.bpmnJS.get('canvas').zoom('fit-viewport');
            }
        });
        this.bpmnJS.on('create.ended', (obj) => {
            this.createEnded.emit(obj);
        });
        this.bpmnJS.on('connection.added', (obj) => {
            this.connectionAdded.emit(obj);
        });
        this.bpmnJS.on('connection.removed', (obj) => {
            this.connectionRemoved.emit(obj);
        });
        this.bpmnJS.on('shape.removed', (obj) => {
            this.shapeRemoved.emit(obj);
        });
    }
    loadUrl(url) {
        return (this.http.get(url, { responseType: 'text' }).pipe(switchMap((xml) => this.importDiagram(xml)), map(result => result.warnings)).subscribe((warnings) => {
            this.importDone.emit({
                type: 'success',
                warnings
            });
        }, (err) => {
            this.importDone.emit({
                type: 'error',
                error: err
            });
        }));
    }
    ngAfterContentInit() {
        this.bpmnJS.attachTo(this.el.nativeElement);
    }
    ngOnChanges(changes) {
        // re-import whenever the url changes
        if (changes['url']) {
            this.loadUrl(changes['url'].currentValue);
        }
    }
    ngOnDestroy() {
        this.bpmnJS.destroy();
    }
    /**
     * Creates a Promise to import the given XML into the current
     * BpmnJS instance, then returns it as an Observable.
     *
     * @see https://github.com/bpmn-io/bpmn-js-callbacks-to-promises#importxml
     */
    importDiagram(xml) {
        return from(this.bpmnJS.importXML(xml));
    }
}
NgxThreeoBpmnComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.1.0", ngImport: i0, type: NgxThreeoBpmnComponent, deps: [{ token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Component });
NgxThreeoBpmnComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.1.0", type: NgxThreeoBpmnComponent, selector: "ngx-threeo-bpmn", inputs: { url: "url" }, outputs: { importDone: "importDone", createEnded: "createEnded", connectionAdded: "connectionAdded", connectionRemoved: "connectionRemoved", shapeRemoved: "shapeRemoved" }, viewQueries: [{ propertyName: "el", first: true, predicate: ["ref"], descendants: true, static: true }], usesOnChanges: true, ngImport: i0, template: `<div #ref class="diagram-container"></div>`, isInline: true, styles: [".diagram-container{height:100%;width:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.1.0", ngImport: i0, type: NgxThreeoBpmnComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-threeo-bpmn', template: `<div #ref class="diagram-container"></div>`, styles: [".diagram-container{height:100%;width:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: i1.HttpClient }]; }, propDecorators: { el: [{
                type: ViewChild,
                args: ['ref', { static: true }]
            }], importDone: [{
                type: Output
            }], createEnded: [{
                type: Output
            }], connectionAdded: [{
                type: Output
            }], connectionRemoved: [{
                type: Output
            }], shapeRemoved: [{
                type: Output
            }], url: [{
                type: Input
            }] } });

class NgxThreeoBpmnModule {
}
NgxThreeoBpmnModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.1.0", ngImport: i0, type: NgxThreeoBpmnModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxThreeoBpmnModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.1.0", ngImport: i0, type: NgxThreeoBpmnModule, declarations: [NgxThreeoBpmnComponent], exports: [NgxThreeoBpmnComponent] });
NgxThreeoBpmnModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.1.0", ngImport: i0, type: NgxThreeoBpmnModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.1.0", ngImport: i0, type: NgxThreeoBpmnModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        NgxThreeoBpmnComponent
                    ],
                    imports: [],
                    exports: [
                        NgxThreeoBpmnComponent
                    ]
                }]
        }] });

/*
 * Public API Surface of ngx-threeo-bpmn
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxThreeoBpmnComponent, NgxThreeoBpmnModule };
//# sourceMappingURL=ngx-threeo-bpmn.mjs.map
